@@ -5,7 +5,7 @@
 package Lingua::Interset::Tagset::GRC::Conll;
 use strict;
 use warnings;
-our $VERSION = '3.003';
+our $VERSION = '3.004';
 
 use utf8;
 use open ':utf8';
@@ -145,7 +145,7 @@ sub _create_atoms
             # The tagset defines gerund and gerundive, probably because it is used also for Latin.
             # Neither of them occurs in in the Ancient Greek data.
             'd' => ['verbform' => 'ger'], ###!!! gerund
-            'g' => ['verbform' => 'ger'], ###!!! gerundive
+            'g' => ['verbform' => 'gdv'], ###!!! gerundive
         },
         'encode_map' =>
         {
@@ -156,7 +156,8 @@ sub _create_atoms
                                                     'imp' => 'm',
                                                     '@'   => '-' }},
                             'part' => 'p',
-                            'ger'  => 'g',
+                            'ger'  => 'd',
+                            'gdv'  => 'g',
                             '@'    => '-' }
         }
     );
@@ -1273,7 +1274,7 @@ Lingua::Interset::Tagset::GRC::Conll - Driver for the tagset of the Ancient Gree
 
 =head1 VERSION
 
-version 3.003
+version 3.004
 
 =head1 SYNOPSIS
 
